@@ -6,6 +6,7 @@ import ckanext.relationship.logic.auth as auth
 import ckanext.relationship.logic.validators as validators
 import ckanext.scheming.helpers as sch
 from ckan.lib.search import rebuild
+from ckan.logic import NotFound
 
 
 class RelationshipPlugin(plugins.SingletonPlugin):
@@ -40,10 +41,10 @@ class RelationshipPlugin(plugins.SingletonPlugin):
 
     # IPackageController
     def after_create(self, context, pkg_dict):
-        return _update_relations(pkg_dict)
+        return _update_relations(context, pkg_dict)
 
     def after_update(self, context, pkg_dict):
-        return _update_relations(pkg_dict)
+        return _update_relations(context, pkg_dict)
 
     def before_index(self, pkg_dict):
         pkg_id = pkg_dict['id']
@@ -71,21 +72,26 @@ def _get_relations_info(schema):
             for field in schema['dataset_fields'] if 'relationship_related_entity' in field.get('validators', '')]
 
 
-def _update_relations(pkg_dict):
+def _update_relations(context, pkg_dict):
     subject_id = pkg_dict['id']
     add_relations = pkg_dict.get('add_relations', [])
     del_relations = pkg_dict.get('del_relations', [])
     for object_id, relation_type in add_relations + del_relations:
         if (object_id, relation_type) in add_relations:
-            tk.get_action('relationship_relation_create')({}, {'subject_id': subject_id,
+            tk.get_action('relationship_relation_create')(context, {'subject_id': subject_id,
                                                                'object_id': object_id,
                                                                'relation_type': relation_type
                                                                })
         else:
-            tk.get_action('relationship_relation_delete')({}, {'subject_id': subject_id,
+            tk.get_action('relationship_relation_delete')(context, {'subject_id': subject_id,
                                                                'object_id': object_id,
                                                                'relation_type': relation_type
                                                                })
-        rebuild(object_id)
+        
+        try:
+            tk.get_action('package_show')({context}, {'id': object_id})
+            rebuild(object_id)
+        except NotFound:
+            pass
     rebuild(subject_id)
     return pkg_dict
